##  Changing Template Layouts
Template layouts are computed automatically. When you drag a shape, it snaps back to its calculated position. By default, templates use a horizontal flow.
To change the layout to a vertical flow:
  1. Open the template editor.
  2. From the layout drop-down list, choose Vertical Flow.


Changing the Template Layout
![A gif of application, organization, and business capability nodes. The layout drop-down menu is used to switch the layout from horizontal to vertical.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio82537967560d420a871b41ee2c02cc52_LowRes.gif)
